@@ -1,5 +1,5 @@
 """
-Copyright (c) 2008-2015, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2017, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -844,8 +844,8 @@ class BasicTransactionTestCase(BasicTestCase):
         self.assertEqual(txn.get_name(), "")
         txn.set_name("XXYY")
         self.assertEqual(txn.get_name(), "XXYY")
-        txn.set_name("")
-        self.assertEqual(txn.get_name(), "")
+        txn.set_name("ABC")
+        self.assertEqual(txn.get_name(), "ABC")
         txn.abort()
 
     #----------------------------------------
